@@ -50,14 +50,14 @@ function _aws_cdk_aws_networkmanager_CfnDevice(p) {
 }
 function _aws_cdk_aws_networkmanager_CfnDevice_LocationProperty(p) {
 }
-function _aws_cdk_aws_networkmanager_CfnSite(p) {
-}
-function _aws_cdk_aws_networkmanager_CfnSite_LocationProperty(p) {
-}
 function _aws_cdk_aws_networkmanager_CfnLink(p) {
 }
 function _aws_cdk_aws_networkmanager_CfnLink_BandwidthProperty(p) {
 }
+function _aws_cdk_aws_networkmanager_CfnSite(p) {
+}
+function _aws_cdk_aws_networkmanager_CfnSite_LocationProperty(p) {
+}
 function print(name, deprecationMessage) {
     const deprecated = process.env.JSII_DEPRECATED;
     const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
@@ -73,5 +73,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_networkmanager_CfnTransitGatewayRegistrationProps, _aws_cdk_aws_networkmanager_CfnLinkAssociationProps, _aws_cdk_aws_networkmanager_CfnCustomerGatewayAssociationProps, _aws_cdk_aws_networkmanager_CfnGlobalNetworkProps, _aws_cdk_aws_networkmanager_CfnLinkProps, _aws_cdk_aws_networkmanager_CfnDeviceProps, _aws_cdk_aws_networkmanager_CfnSiteProps, _aws_cdk_aws_networkmanager_CfnCustomerGatewayAssociation, _aws_cdk_aws_networkmanager_CfnLinkAssociation, _aws_cdk_aws_networkmanager_CfnTransitGatewayRegistration, _aws_cdk_aws_networkmanager_CfnGlobalNetwork, _aws_cdk_aws_networkmanager_CfnDevice, _aws_cdk_aws_networkmanager_CfnDevice_LocationProperty, _aws_cdk_aws_networkmanager_CfnSite, _aws_cdk_aws_networkmanager_CfnSite_LocationProperty, _aws_cdk_aws_networkmanager_CfnLink, _aws_cdk_aws_networkmanager_CfnLink_BandwidthProperty };
+module.exports = { print, _aws_cdk_aws_networkmanager_CfnTransitGatewayRegistrationProps, _aws_cdk_aws_networkmanager_CfnLinkAssociationProps, _aws_cdk_aws_networkmanager_CfnCustomerGatewayAssociationProps, _aws_cdk_aws_networkmanager_CfnGlobalNetworkProps, _aws_cdk_aws_networkmanager_CfnLinkProps, _aws_cdk_aws_networkmanager_CfnDeviceProps, _aws_cdk_aws_networkmanager_CfnSiteProps, _aws_cdk_aws_networkmanager_CfnCustomerGatewayAssociation, _aws_cdk_aws_networkmanager_CfnLinkAssociation, _aws_cdk_aws_networkmanager_CfnTransitGatewayRegistration, _aws_cdk_aws_networkmanager_CfnGlobalNetwork, _aws_cdk_aws_networkmanager_CfnDevice, _aws_cdk_aws_networkmanager_CfnDevice_LocationProperty, _aws_cdk_aws_networkmanager_CfnLink, _aws_cdk_aws_networkmanager_CfnLink_BandwidthProperty, _aws_cdk_aws_networkmanager_CfnSite, _aws_cdk_aws_networkmanager_CfnSite_LocationProperty };
 module.exports.DeprecationError = DeprecationError;
